# CMeel libdrm

[![PyPI version](https://badge.fury.io/py/cmeel-mpc.svg)](https://pypi.org/project/cmeel-mpc)
[![Release](https://github.com/cmake-wheel/cmeel-mpc/actions/workflows/release.yml/badge.svg)](https://github.com/cmake-wheel/cmeel-mpc/actions/workflows/release.yml)

[libdrm](https://dri.freedesktop.org) distribution for cmeel packages.
